@@ -1,22 +1,21 @@
 ###__PERLBIN__###
-#  Copyright (C) 2002-2005 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    This program is free software; you can redistribute it and/or modify
+#    GNUpod is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
+#    the Free Software Foundation; either version 3 of the License, or
 #    (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
+#    GNUpod is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -24,7 +23,7 @@
 
 use strict;
 use GNUpod::FooBar;
-
+use GNUpod::FileMagic;
 
 
 my $file  = $ARGV[0] or exit(1);
@@ -37,7 +36,8 @@ if(!(-r $file)) {
  exit(1);
 }
 elsif($gimme eq "GET_META") {
-  print "FORMAT: MIDI\n";
+  print "_MEDIATYPE:".(GNUpod::FileMagic::MEDIATYPE_AUDIO)."\n";
+  print "FORMAT:MIDI\n";
 }
 elsif($gimme eq "GET_PCM") {
   my $tmpout = GNUpod::FooBar::get_u_path("/tmp/gnupod_pcm", "wav");
@@ -58,6 +58,8 @@ elsif($gimme eq "GET_MP3") {
   my $tmpout = GNUpod::FooBar::get_u_path("/tmp/gnupod_mp3", "mp3");
   open(MIDIOUT, "-|") or exec("timidity", "-idqq", "-Ow", "-o", "-", $file) or die "Could not exec timidity: $!\n";
   open(LAMEIN , "|-") or exec("lame", "-V", $quality, "--silent", "-", $tmpout) or die "Could not exec lame: $!\n";
+  binmode(MIDIOUT);
+  binmode(LAMEIN);
    while(<MIDIOUT>) {
     print LAMEIN $_;
    }
@@ -71,6 +73,8 @@ elsif($gimme eq "GET_AAC" or $gimme eq "GET_AACBM") {
   $quality = 140 - ($quality*10);
   open(MIDIOUT, "-|") or exec("timidity", "-idqq", "-Ow", "-o", "-", $file) or die "Could not exec timidity: $!\n";
   open(FAACIN , "|-") or exec("faac", "-w", "-q", $quality, "-o", $tmpout, "-") or die "Could not exec faac: $!\n";
+  binmode(MIDIOUT);
+  binmode(FAACIN);
    while(<MIDIOUT>) { #Feed faac
     print FAACIN $_;
    }
